@@ -1,4 +1,6 @@
+import dbm
 import errno
+import pickle
 import sys
 from datetime import datetime, timedelta, timezone
 from pickle import dumps, loads
@@ -688,6 +690,45 @@ class test_PersistentScheduler:
         s._create_schedule()
         s._destroy_open_corrupted_schedule.assert_called_with(expected_error)
 
+    def test_create_schedule_corrupted_dbm_error(self):
+        """
+        Test that any dbm.error that might happen when opening beat-schedule.db are caught
+        """
+        s = create_persistent_scheduler()[0](app=self.app,
+                                             schedule_filename='schedule')
+        s._store = MagicMock()
+        s._destroy_open_corrupted_schedule = Mock()
+        s._destroy_open_corrupted_schedule.return_value = MagicMock()
+
+        # self._store['entries'] = {} will throw a KeyError
+        s._store.__getitem__.side_effect = KeyError()
+        # then, when _create_schedule tries to reset _store['entries'], throw another error, specifically dbm.error
+        expected_error = dbm.error[0]()
+        s._store.__setitem__.side_effect = expected_error
+
+        s._create_schedule()
+        s._destroy_open_corrupted_schedule.assert_called_with(expected_error)
+
+    def test_create_schedule_corrupted_pickle_error(self):
+        """
+        Test that any UnpicklingError that might happen when opening beat-schedule.db is caught
+        """
+        s = create_persistent_scheduler()[0](app=self.app,
+                                             schedule_filename='schedule')
+        s._store = MagicMock()
+        s._destroy_open_corrupted_schedule = Mock()
+        s._destroy_open_corrupted_schedule.return_value = MagicMock()
+
+        # self._store['entries'] = {} will throw a pickle.UnpicklingError
+        s._store.__getitem__.side_effect = pickle.UnpicklingError("test")
+        # then, when _create_schedule tries to reset _store['entries'],
+        # throw another error, specifically pickle.UnpicklingError
+        expected_error = pickle.UnpicklingError("test")
+        s._store.__setitem__.side_effect = expected_error
+
+        s._create_schedule()
+        s._destroy_open_corrupted_schedule.assert_called_with(expected_error)
+
     def test_create_schedule_missing_entries(self):
         """
         Test that if _create_schedule can't find the key "entries" in _store it will recreate it
